# API Roadmap

## 💪 v1 - Foundational: Rich synchronous functionality

v1 is all about creating a strong foundation for the library:

* 🛠️ Rich functionality
* ⚡️ High performance
* 💯 Test coverage
* 💯 Documentation coverage

## 🔀 v2 - Async over Sync: Async functionality over sync iterables

Although v1 is still going strong, we are already planning for the future.
We plan to add async functionality to the library to boost performance even further, while
keeping the API simple and clean.

## 🚀 v3 - Async over Async: Async functionality over async iterables

Our longer term goal is to complete the entire async functionality, 
by adding support for async iterables.
